Crate cloudfront_policy_signer
cloudfront_
policy_
signer
0.1.3
All Items
Crate Items
Structs
Enums
Functions
Crate
cloudfront_
policy_
signer
Structs

Cloud
Front
Canned
Policy
Signer
Struct to create a URL from CloudFront with a cached private key Unliked method
create_canned_policy_signature
, calling
create_canned_policy_signature_url
in an instance of this struct will not read the private key file every time it is invoked.
Enums

Error
Enumeration of all possible errors returned by the crate
Functions

create_
canned_
policy_
signature
Signs a canned policy with the specified path and expiration date and returns it in an URL safe format appropriate for AWS.