pub enum Error {
IOError(Error),
PrivateKeyParseError,
PrivateKeyConvertError,
CouldNotSign,
Unknown,
}Expand description
Enumeration of all possible errors returned by the crate
Variants
IOError(Error)
We received an IO error from the operating system. Refer to std::io::Error for more information
PrivateKeyParseError
The private key was in an unsupported format or somehow malformed. It only accepts keys in PEM-encoded PKCS#1
PrivateKeyConvertError
The key could not be converted from a openssl::rsa::Rsa<openssl::pkey::Private> to a PKey<Private>
CouldNotSign
The policy could not be signed. Refer to the error printed out in the logs
Unknown
Blanket error for all errors from OpenSSL that should not occur, but can due to it being written in unsafe C.